@@ -32,7 +32,6 @@ from tlslite import *
 
 try:
     from tack.structures.Tack import Tack
-    from tack.structures.TackBreakSig import TackBreakSig
     
 except ImportError:
     pass
@@ -117,37 +116,16 @@ def clientTestCmd(argv):
                     
         settings = HandshakeSettings()
         settings.useExperimentalTackExtension = True
-        
-        print "Test 2.a - good X.509, TACK and Break Sigs"
+
+        print "Test 2.a - good X.509, TACK"
         connection = connect()
         connection.handshakeClientCert(settings=settings)
-        assert(connection.session.tackExt.tack.getTackId() == "rrted.ptvtl.d2uiq.ox2xe.w4ss3")
-        assert(connection.session.tackExt.break_sigs[0].getTackId() == "nxt3o.zoovj.xq5qk.mue76.wmx6t")
-        assert(connection.session.tackExt.break_sigs[1].getTackId() == "neuda.jg26x.ixmom.wzdry.qxdii")
-        assert(connection.session.tackExt.pin_activation == False)
+        assert(connection.session.tackExt.tacks[0].getTackId() == "rrted.ptvtl.d2uiq.ox2xe.w4ss3")
+        assert(connection.session.tackExt.activation_flags == 1)        
         testConnClient(connection)    
         connection.close()    
 
-        print "Test 2.b - good X.509, TACK without Break Sigs"
-        connection = connect()
-        connection.handshakeClientCert(settings=settings)
-        assert(connection.session.tackExt.tack.getTackId() == "rrted.ptvtl.d2uiq.ox2xe.w4ss3")
-        assert(not connection.session.tackExt.break_sigs)
-        assert(connection.session.tackExt.pin_activation == True)        
-        testConnClient(connection)    
-        connection.close()    
-
-        print "Test 2.c - good X.509, Break Sigs without TACK"
-        connection = connect()
-        connection.handshakeClientCert(settings=settings)
-        assert(connection.session.tackExt.tack == None)
-        assert(connection.session.tackExt.break_sigs[0].getTackId() == "nxt3o.zoovj.xq5qk.mue76.wmx6t")
-        assert(connection.session.tackExt.break_sigs[1].getTackId() == "neuda.jg26x.ixmom.wzdry.qxdii")
-        assert(connection.session.tackExt.pin_activation == True)
-        testConnClient(connection)    
-        connection.close()    
-
-        print "Test 2.d - good X.509, TACK unrelated to cert chain"
+        print "Test 2.b - good X.509, TACK unrelated to cert chain"
         connection = connect()
         try:
             connection.handshakeClientCert(settings=settings)
@@ -441,38 +419,22 @@ def serverTestCmd(argv):
     if tackpyLoaded:
         tack = Tack.createFromPem(open("./TACK1.pem", "rU").read())
         tackUnrelated = Tack.createFromPem(open("./TACKunrelated.pem", "rU").read())    
-        breakSigs = TackBreakSig.createFromPemList(
-            open("./TACK_Break_Sigs.pem").read())
             
         settings = HandshakeSettings()
         settings.useExperimentalTackExtension = True
 
-        print "Test 2.a - good X.509, TACK and Break Sigs"
+        print "Test 2.a - good X.509, TACK"
         connection = connect()
         connection.handshakeServer(certChain=x509Chain, privateKey=x509Key,
-            tack=tack, breakSigs=breakSigs, settings=settings)
+            tacks=[tack], activationFlags=1, settings=settings)
         testConnServer(connection)    
         connection.close()        
 
-        print "Test 2.b - good X.509, TACK without Break Sigs"
-        connection = connect()
-        connection.handshakeServer(certChain=x509Chain, privateKey=x509Key,
-            tack=tack, pinActivation=True, settings=settings)
-        testConnServer(connection)    
-        connection.close()        
-
-        print "Test 2.c - good X.509, Break Sigs without TACK"
-        connection = connect()
-        connection.handshakeServer(certChain=x509Chain, privateKey=x509Key,
-            breakSigs=breakSigs, pinActivation=True, settings=settings)
-        testConnServer(connection)    
-        connection.close()        
-
-        print "Test 2.d - good X.509, TACK unrelated to cert chain"
+        print "Test 2.b - good X.509, TACK unrelated to cert chain"
         connection = connect()
         try:
             connection.handshakeServer(certChain=x509Chain, privateKey=x509Key,
-                tack=tackUnrelated, breakSigs=breakSigs, settings=settings)
+                tacks=[tackUnrelated], settings=settings)
             assert(False)
         except TLSRemoteAlert, alert:
             if alert.description != AlertDescription.illegal_parameter:
